@@ -84,6 +84,6 @@ class HierarchyElement:
             return self.document_x0 < other.document_x0
 
     def __str__(self):
-        s = f"{self.text_content.strip() if self.text_content.strip() != '' else self.class_name}"\
-            # f"(x{self.page_x0},y{self.page_y0}),(x{self.page_x1},y{self.page_y1})"
+        # Used during serialization to JSON
+        s = f"{self.text_content.strip() if self.text_content.strip() != '' else self.class_name}"
         return s
